@@ -40,7 +40,7 @@ sub import {
     *{"${caller}::has"} = sub { attr($caller, @_) };
   }
 
-  # Mojo modules are strict!
+  # Evo modules are strict and use cool features
   $_->import for qw(strict warnings utf8);
   feature->import(':5.20', 'signatures', 'postderef');
   warnings->unimport('experimental::signatures', 'experimental::postderef');
@@ -107,7 +107,7 @@ Evo::Base
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -135,7 +135,7 @@ version 0.006
 
 =head1 DESCRIPTION
 
-L<Evo::Base> is a simple base class for L<Mojo> projects.
+L<Evo::Base> is a simple base class for L<Evo> projects.
 
   # Automatically enables "strict", "warnings", "utf8" and Perl 5.10 features
   use Evo::Base -strict;
@@ -178,7 +178,7 @@ All three forms save a lot of typing.
 
 =head1 NAME
 
-Evo::Base - Minimal base class. Almost a copypast from Evo::Base
+Evo::Base - Minimal base class. Almost copypast from L<Mojo::Base>
 Will be changed to Moo in the future
 
 =head1 FUNCTIONS
@@ -252,7 +252,7 @@ diagnostics information printed to C<STDERR>.
 
 =head1 SEE ALSO
 
-L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
+L<Mojolicious>
 
 =head1 AUTHOR
 
